Module table

Module table 

Structs

Table
Represents a database table utilizing a BTreeMap for underlying data storage. Needs the PrimaryKey trait to be implemented for the value type. Offers enhanced methods for manipulating records, including add, edit, delete, get, and search.

Traits

PrimaryKey
Trait for getting the value of the primary key
TableKey
Trait alias-like bound for primary key types supported by Table.